@@ -1,18 +1,18 @@
-# Copyrights 2004-2018 by [Mark Overmeer].
+# Copyrights 2004-2025 by [Mark Overmeer <markov@cpan.org>].
 #  For other contributors see ChangeLog.
 # See the manual pages for details on the licensing terms.
-# Pod stripped from pm file by OODoc 2.02.
-# This code is part of distribution Math::Polygon.  Meta-POD processed with
+# Pod stripped from pm file by OODoc 2.03.
+# This code is part of distribution Math-Polygon.  Meta-POD processed with
 # OODoc into POD and HTML manual-pages.  See README.md
 # Copyright Mark Overmeer.  Licensed under the same terms as Perl itself.
 
 # Algorithm by Dan Sunday
 # - http://geometryalgorithms.com/Archive/algorithm_0109/algorithm_0109.htm
-# Original implementation in Perl by Jari Turkia.
+# Original contributed implementation in Perl by Jari Turkia.
 
-package Math::Polygon::Convex;
-use vars '$VERSION';
-$VERSION = '1.10';
+package Math::Polygon::Convex;{
+our $VERSION = '1.11';
+}
 
 use base 'Exporter';
 
